@@ -71,7 +71,7 @@ def pre_process_raw(df,atts,ngrams=2,pad=False,return_type='qid'):
     return ldf, media_ngram, maior
 
 def extract_sample(df1,sample_size,duplicate_rate=0.1,
-                    df2=False,
+                    df2=[],
                     return_raw_sample=False,
                     return_type='qid',
                     atts='all'
@@ -89,11 +89,15 @@ def extract_sample(df1,sample_size,duplicate_rate=0.1,
     assert duplicate_rate <= 1
     assert duplicate_rate > 0
 
+    df2_flag = False
+    if len(df2) > 0:
+        df2_flag = True
+
     num_of_duplicated_records_df_b = int(sample_size * duplicate_rate)
     num_of_no_duplicated_records_df_b = sample_size - num_of_duplicated_records_df_b
     
     df_a = df1.sample(sample_size)
-    if df2 == False:
+    if df2_flag == False:
         df_b = pd.concat([df1.sample(num_of_no_duplicated_records_df_b),
                             df_a.sample(num_of_duplicated_records_df_b) #corrigido
                         ])
