@@ -64,7 +64,7 @@ def rank_dataset(df_a,df_b,bf_representation='binary',bit_power=1,blk=[]):
   '''
   
   if len(blk) == 0:
-    return __rank_all_dataset(df_a,df_b,bf_representation='binary',bit_power=1)
+    return __rank_all_dataset(df_a,df_b,bf_representation=bf_representation,bit_power=bit_power)
   else:
     ds = []
     #converte para DataFrame para facilitar
