@@ -21,6 +21,18 @@ def block_dataset(raw_dfa,raw_dfb,blk_att_a,blk_att_b,
         - id_b : id attribute (default: voter_id)
         - key_lenght : key kength
     """
+
+    if type(raw_dfa) == list:
+      raw_dfa = pd.DataFrame(raw_dfa)
+      raw_dfa.columns = ['id','val']
+      raw_dfb = pd.DataFrame(raw_dfb)
+      raw_dfb.columns = ['id','val']
+
+      blk_att_a = 'val'
+      blk_att_b = 'val'
+      id_a = 'id'
+      id_b = 'id'
+
     raw_dfa['BLK'] = raw_dfa[blk_att_a].str[:key_lenght]
     raw_dfb['BLK'] = raw_dfb[blk_att_b].str[:key_lenght]
 
